@@ -6,13 +6,12 @@ Created on Sat Oct 24 18:24:20 2020
 @author: Martín Carlos Araya <martinaraya@gmail.com>
 """
 
-__version__ = '0.2.7'
-__release__ = 20220908
+__version__ = '0.3.0'
+__release__ = 20220919
+__all__ = ['units', 'convert']
 
-# from .units.custom import *
 from .units.define import units
-#from ._convert import convertUnit
-#from ._convert import convertUnit_old as convert_old  # mainteined while testing
+from ._convert import convertUnit
 from ._convert import convertUnit as convert
 
 def print_path(switch=None):
