@@ -7,8 +7,8 @@ Created on Sat Oct 24 12:36:48 2020
 """
 
 __all__ = ['unitsNetwork']
-__version__ = '0.1.2'
-__release__ = 20220826
+__version__ = '0.2.7'
+__release__ = 20220908
 
 from ._dictionaries import SI, SI_order, OGF, OGF_order, DATA, DATA_order, dictionary, StandardAirDensity, StandadEarthGravity
 
@@ -31,7 +31,7 @@ class uDigraph(object):
         self.fvf = None
         self.Memory = {}
         self.fvf = None
-        self.print = True
+        self.print = False
 
     def addNode(self, node):
         if node in self.edges:
@@ -169,6 +169,12 @@ def _loadNetwork():
                     network.addEdge(conversion(network.getNode(secondName), network.getNode(unitName), lambda X: X))
                     network.addEdge(conversion(network.getNode(unitName), network.getNode(secondName), lambda X: X))
                     dictionary[unitKind.split('_')[0]].append(secondName)
+                # for secondName in dictionary[unitKind][unitName]:
+                #     for t in range(dictionary[unitKind][unitName].index(secondName)+1, len(dictionary[unitKind][unitName])):
+                #         thirdName = dictionary[unitKind][unitName][t]
+                #         network.addEdge(conversion(network.getNode(secondName), network.getNode(thirdName), lambda X: X))
+                #         network.addEdge(conversion(network.getNode(thirdName), network.getNode(secondName), lambda X: X))
+
 
         if '_SPACES' in unitKind:
             for unitName in list(dictionary[unitKind].keys()):
@@ -349,14 +355,15 @@ def _loadNetwork():
     #         for unitNode in
 
     # percentage & fraction :
-    network.addEdge(conversion(network.getNode('fraction'), network.getNode('percentage'), lambda f: f*100))
+    network.addEdge(conversion(network.getNode('fraction'), network.getNode('percentage'), lambda f: f * 100))
+    network.addEdge(conversion(network.getNode('percentage'), network.getNode('fraction'), lambda p: p / 100))
 
     # time conversions
     # network.addEdge(conversion(network.getNode('second'), network.getNode('millisecond'), lambda t: t*1000))
     network.addEdge(conversion(network.getNode('minute'), network.getNode('second'), lambda t: t*60))
     network.addEdge(conversion(network.getNode('hour'), network.getNode('minute'), lambda t: t*60))
     network.addEdge(conversion(network.getNode('day'), network.getNode('hour'), lambda t: t*24))
-    network.addEdge(conversion(network.getNode('day'), network.getNode('month'), lambda t: t/36525/100*12))
+    network.addEdge(conversion(network.getNode('day'), network.getNode('month'), lambda t: t/365.25*12))
     network.addEdge(conversion(network.getNode('week'), network.getNode('day'), lambda t: t*7))
     network.addEdge(conversion(network.getNode('year'), network.getNode('month'), lambda t: t*12))
     network.addEdge(conversion(network.getNode('year'), network.getNode('day'), lambda t: t*36525/100))
@@ -371,8 +378,8 @@ def _loadNetwork():
     network.addEdge(conversion(network.getNode('Fahrenheit'), network.getNode('Celsius'), lambda t: (t-32) * 5/9))
     network.addEdge(conversion(network.getNode('Fahrenheit'), network.getNode('Rankine'), lambda t: t+459.67))
     network.addEdge(conversion(network.getNode('Rankine'), network.getNode('Fahrenheit'), lambda t: t-459.67))
-    network.addEdge(conversion(network.getNode('Rankine'), network.getNode('Kelvin'), lambda t: t*9/5))
-    network.addEdge(conversion(network.getNode('Kelvin'), network.getNode('Rankine'), lambda t: t*5/9))
+    network.addEdge(conversion(network.getNode('Rankine'), network.getNode('Kelvin'), lambda t: t*5/9))
+    network.addEdge(conversion(network.getNode('Kelvin'), network.getNode('Rankine'), lambda t: t*9/5))
 
     # length conversions
     network.addEdge(conversion(network.getNode('yard'), network.getNode('meter'), lambda d: d*9144/10000))
@@ -409,20 +416,20 @@ def _loadNetwork():
     # network.addEdge(conversion(network.getNode('in'), network.getNode('in*in'), lambda d: d**2))
 
     # volume conversions
-    network.addEdge(conversion(network.getNode('gill'), network.getNode('fuild ounce'), lambda v: v*5))
+    network.addEdge(conversion(network.getNode('gill'), network.getNode('fuild ounce'), lambda v: v*4))
     network.addEdge(conversion(network.getNode('pint'), network.getNode('gill'), lambda v: v*4))
     network.addEdge(conversion(network.getNode('quart'), network.getNode('pint'), lambda v: v*2))
     network.addEdge(conversion(network.getNode('gallonUS'), network.getNode('fuild ounce'), lambda v: v*128))
     network.addEdge(conversion(network.getNode('gallonUS'), network.getNode('quart'), lambda v: v*4))
     network.addEdge(conversion(network.getNode('gallonUS'), network.getNode('cubic inch'), lambda v: v*231))
-    
+
     network.addEdge(conversion(network.getNode('gallonUK'), network.getNode('quartUK'), lambda v: v*4))
     network.addEdge(conversion(network.getNode('gallonUK'), network.getNode('fuild ounce UK'), lambda v: v*160))
     network.addEdge(conversion(network.getNode('gallonUK'), network.getNode('litre'), lambda v: v*4.54609))
-    network.addEdge(conversion(network.getNode('gillUK'), network.getNode('fuild ounce UK'), lambda v: v*5))
+    network.addEdge(conversion(network.getNode('gillUK'), network.getNode('fuild ounce UK'), lambda v: v*4))
     network.addEdge(conversion(network.getNode('pintUK'), network.getNode('gillUK'), lambda v: v*4))
     network.addEdge(conversion(network.getNode('quartUK'), network.getNode('pintUK'), lambda v: v*2))
-    
+
     network.addEdge(conversion(network.getNode('gallonUK'), network.getNode('liter'), lambda v: v* 4.54609))
     network.addEdge(conversion(network.getNode('cubic foot'), network.getNode('cubic meter'), lambda v: v*(3048**3)/(10000**3)))
     network.addEdge(conversion(network.getNode('standard cubic foot'), network.getNode('standard cubic meter'), lambda v: v*(3048**3)/(10000**3)))
@@ -436,7 +443,7 @@ def _loadNetwork():
     # pressure conversions
     network.addEdge(conversion(network.getNode('psi gauge'), network.getNode('absolute psi'), lambda p: p+14.6959))
     network.addEdge(conversion(network.getNode('absolute psi'), network.getNode('psi gauge'), lambda p: p-14.6959))
-    network.addEdge(conversion(network.getNode('bar gauge'), network.getNode('bara'), lambda p: p+1.01325))
+    network.addEdge(conversion(network.getNode('bar gauge'), network.getNode('absolute bar'), lambda p: p+1.01325))
     network.addEdge(conversion(network.getNode('absolute bar'), network.getNode('bar gauge'), lambda p: p-1.01325))
 
     network.addEdge(conversion(network.getNode('absolute bar'), network.getNode('absolute psi'), lambda p: p*14.50377377322))
@@ -466,10 +473,20 @@ def _loadNetwork():
 
     # force conversion
     # network.addEdge(conversion(network.getNode('kilogram'), network.getNode('kilogram force'), lambda f: f* converter(StandadEarthGravity,'m/s2','cm/s2',False)))
-    network.addEdge(conversion(network.getNode('kilogram mass'), network.getNode('kilogram force'), lambda f: f* StandadEarthGravity))
+    network.addEdge(conversion(network.getNode('kilogram mass'), network.getNode('kilogram force'), lambda f: f * StandadEarthGravity))
+    network.addEdge(conversion(network.getNode('kilogram force'), network.getNode('kilogram mass'), lambda f: f / StandadEarthGravity))
     network.addEdge(conversion(network.getNode('Dyne'), network.getNode('Newton'), lambda f: f*1E-5))
     network.addEdge(conversion(network.getNode('Newton'), network.getNode('Dyne'), lambda f: f*1E5 ))
 
+    # energy conversion
+    network.addEdge(conversion(network.getNode('Joule'), network.getNode('gram calorie'), lambda e: e/4.184))
+    network.addEdge(conversion(network.getNode('Kilojoule'), network.getNode('Joule'), lambda e: e*1000))
+    network.addEdge(conversion(network.getNode('Kilojoule'), network.getNode('kilowatt hour'), lambda e: e/3600))
+    network.addEdge(conversion(network.getNode('Kilojoule'), network.getNode('British thermal unit'), lambda e: e/1.055))
+
+    # power conversion
+    network.addEdge(conversion(network.getNode('Horsepower'), network.getNode('Watt'), lambda e: e*745.699872))
+
     # density conversion
     network.addEdge(conversion(network.getNode('API'), network.getNode('SgO'), lambda d: 141.5/(131.5+d)))
     network.addEdge(conversion(network.getNode('SgO'), network.getNode('API'), lambda d: 141.5/d-131.5))
@@ -485,7 +502,8 @@ def _loadNetwork():
 
     # data conversions
     network.addEdge(conversion(network.getNode('byte'), network.getNode('bit'), lambda d: d*8))
-    network.addEdge(conversion(network.getNode('bit'), network.getNode('byte'), lambda d: d/8))  # _REVERSE not working here
+    network.addEdge(conversion(network.getNode('byte'), network.getNode('B'), lambda d: d))
+    network.addEdge(conversion(network.getNode('bit'), network.getNode('b'), lambda d: d))
 
     for unitKind in list(dictionary.keys()):
         if '_REVERSE' in unitKind:
@@ -534,78 +552,114 @@ def _loadNetwork():
 def _create_rates():
     # volumes / time
     rates = list(dictionary['rate']) if 'rate' in dictionary else []
-    for volume in dictionary['volume']:
-        for time in dictionary['time']:
-            rates.append(volume+'/'+time)
-    for weight in dictionary['weight']:
-        for time in dictionary['time']:
-            rates.append(weight+'/'+time)
+    # for volume in dictionary['volume']:
+    #     for time in dictionary['time']:
+    #         rates.append(volume+'/'+time)
+    rates += [volume+'/'+time for volume in dictionary['volume'] for time in dictionary['time']]
+    # for weight in dictionary['weight']:
+    #     for time in dictionary['time']:
+    #         rates.append(weight+'/'+time)
+    rates += [weight+'/'+time for weight in dictionary['weight'] for time in dictionary['time']]
     # data / time
-    for data in dictionary['dataBYTE']:
-        for time in dictionary['time']:
-            rates.append(data+'/'+time)
-    for data in dictionary['dataBIT']:
-        for time in dictionary['time']:
-            rates.append(data+'/'+time)
+    # for data in dictionary['dataBYTE']:
+    #     for time in dictionary['time']:
+    #         rates.append(data+'/'+time)
+    rates += [data+'/'+time for data in dictionary['dataBYTE'] for time in dictionary['time']]
+    # for data in dictionary['dataBIT']:
+    #     for time in dictionary['time']:
+    #         rates.append(data+'/'+time)
+    rates += [data+'/'+time for data in dictionary['dataBIT'] for time in dictionary['time']]
     dictionary['rate'] = tuple(set(rates))
 
 
 def _create_volumeRatio():
     # volume / volume
     ratio = list(dictionary['volumeRatio']) if 'volumeRatio' in dictionary else []
-    for numerator in dictionary['volume']:
-        for denominator in dictionary['volume']:
-            ratio.append(numerator+'/'+denominator)
+    # for numerator in dictionary['volume']:
+    #     for denominator in dictionary['volume']:
+    #         ratio.append(numerator+'/'+denominator)
+    ratio += [numerator+'/'+denominator for numerator in dictionary['volume'] for denominator in dictionary['volume']]
     dictionary['volumeRatio'] = tuple(set(ratio))
 
 
 def _create_density():
     # mass / volume
     density = list(dictionary['density']) if 'density' in dictionary else []
-    for numerator in dictionary['mass']:
-        for denominator in dictionary['volume']:
-            density.append(numerator+'/'+denominator)
+    # for mass in dictionary['mass']:
+    #     for volume in dictionary['volume']:
+    #         density.append(mass+'/'+volume)
+    density += [mass+'/'+volume for mass in dictionary['mass'] for volume in dictionary['volume']]
     dictionary['density'] = tuple(set(density))
 
 
 def _create_speed():
     # length / time
     speed = list(dictionary['speed']) if 'speed' in dictionary else []
-    for length in dictionary['length']:
-        for time in dictionary['time']:
-            speed.append(length+'/'+time)
+    # for length in dictionary['length']:
+    #     for time in dictionary['time']:
+    #         speed.append(length+'/'+time)
+    speed += [length+'/'+time for length in dictionary['length'] for time in dictionary['time']]
     dictionary['speed'] = tuple(set(speed))
 
 
+def _create_power():
+    # length / time
+    power = list(dictionary['power']) if 'power' in dictionary else []
+    # for energy in dictionary['energy']:
+    #     for time in dictionary['time']:
+    #         power.append(energy+'/'+time)
+    power += [energy+'/'+time for energy in dictionary['energy'] for time in dictionary['time']]
+    dictionary['power'] = tuple(set(power))
+
+
 def _create_productivityIndex():
     # volume / time / pressure
     productivityIndex = list(dictionary['productivityIndex']) if 'productivityIndex' in dictionary else []
-    for volume in dictionary['volume']:
-        for time in dictionary['time']:
-            for pressure in dictionary['pressure']:
-                productivityIndex.append(volume+'/'+time+'/'+pressure)
+    # for volume in dictionary['volume']:
+    #     for time in dictionary['time']:
+    #         for pressure in dictionary['pressure']:
+    #             productivityIndex.append(volume+'/'+time+'/'+pressure)
+    productivityIndex += [volume+'/'+time+'/'+pressure
+                          for volume in dictionary['volume']
+                          for time in dictionary['time']
+                          for pressure in dictionary['pressure']]
     dictionary['productivityIndex'] = tuple(set(productivityIndex))
 
 
 def _create_pressureGradient():
     # pressure / length
     pressureGradient = list(dictionary['pressureGradient']) if 'pressureGradient' in dictionary else []
-    for pressure in dictionary['pressure']:
-        for length in dictionary['length']:
-            pressureGradient.append(pressure+'/'+length)
+    # for pressure in dictionary['pressure']:
+    #     for length in dictionary['length']:
+    #         pressureGradient.append(pressure+'/'+length)
+    pressureGradient += [pressure+'/'+length for pressure in dictionary['pressure'] for length in dictionary['length']]
     dictionary['pressureGradient'] = tuple(set(pressureGradient))
-    
+
+
+def _create_temperatureGradient():
+    # pressure / length
+    temperatureGradient = list(dictionary['temperatureGradient']) if 'temperatureGradient' in dictionary else []
+    # for pressure in dictionary['pressure']:
+    #     for length in dictionary['length']:
+    #         pressureGradient.append(pressure+'/'+length)
+    temperatureGradient += [temperature+'/'+length for temperature in dictionary['temperature'] for length in dictionary['length']]
+    dictionary['temperatureGradient'] = tuple(set(temperatureGradient))
+
 
 def _create_acceleration():
     # length / time / time
     acceleration = list(dictionary['acceleration']) if 'acceleration' in dictionary else []
-    for length in dictionary['length']:
-        for time1 in dictionary['time']:
-            for time2 in dictionary['time']:
-                if time1 == time2:
-                    acceleration.append(length+'/'+time1+'2')
-                else:
-                    acceleration.append(length+'/'+time1+'/'+time2)
+    # for length in dictionary['length']:
+    #     for time1 in dictionary['time']:
+    #         for time2 in dictionary['time']:
+    #             if time1 == time2:
+    #                 acceleration.append(length+'/'+time1+'2')
+    #             else:
+    #                 acceleration.append(length+'/'+time1+'/'+time2)
+    acceleration += [(length+'/'+time1+'2') if time1 == time2 else (length+'/'+time1+'/'+time2)
+                     for length in dictionary['length']
+                     for time1 in dictionary['time']
+                     for time2 in dictionary['time']]
     dictionary['acceleration'] = tuple(set(acceleration))
 
 
@@ -619,6 +673,8 @@ _create_density()
 _create_speed()
 _create_productivityIndex()
 _create_pressureGradient()
+_create_temperatureGradient()
+_create_power()
 
 
 def network2Frame():
